function N = vneutraldens2(species,r,sza,aza)

% VNEUTRALDENS2('species',r,sza,aza)
%      gives the density at distance r from the centre of Venus for 
%      the neutral species 'species'
%      sza is the solar zenith angle and aza is the azimuthal angle,
%      that is the angle between the positive y-axis and the projection 
%      of the r-vector on to the yz-plane
%      H_the, H_hot, O_the, O_hot and He are the only neutral species allowed. 
%
%      The density is given in m^{-3}
%      
%      HG 2002-12-03
%      This is simply a new version of vneutraldens that takes vector 
%      inputs for r, sza, and aza.  HG 2003-09-04

if nargin<3, error('Can I have some more input arguments, please.'); end
if min(sza)<0 | max(sza)>pi, 
    error(['When a true genius appears in the world, you may know him by ' ...
	   'this sign, that the dunces are all in confederacy against him.'])
end
aza=mod(aza,2*pi);

rv=6051.8e3;

switch species 
  case 'H_the'
    zi1 = sza<pi/2;                % True on the dayside
    zi2 = ~zi1 & sza<2*pi/3;       % True on nightside and SZA < 120 deg
    zi3 = ~zi1 & ~zi2 & sza<5*pi/6;% True on nightside and 120 < SZA < 150 deg
    zi4 = ~zi1 & ~zi2 & ~zi3;      % True if SZA >150 deg
    ai1 = aza<pi/6 | aza>11*pi/6;  % True in the bulge
    ai2 = ~ai1;                    % True outside the bulge
    
    % Are we on the dayside?
    r0(zi1)=rv+170e3; hs(zi1) = 1.382e8; n0(zi1) = 1.32e11;            % [1,4]
    % Then we're on the nightside
    % Are we in the bulge?
    r0(zi2 & ai1)=rv+170e3;hs(zi2 & ai1)=3.58e8;n0(zi2 & ai1)=2.93e12; % [1,4]
    r0(zi3 & ai1)=rv+170e3;hs(zi3 & ai1)=3.58e8;n0(zi3 & ai1)=1.13e13; % [1,4]
    r0(zi4 & ai1)=rv+170e3;hs(zi4 & ai1)=3.58e8;n0(zi4 & ai1)=6.92e12; % [1,4]
    % Then we're outside the bulge
    r0(zi2 & ai2)=rv+170e3;hs(zi2 & ai2)=3.58e8;n0(zi2 & ai2)=3.55e11; % [1,4]
    r0(zi3 & ai2)=rv+170e3;hs(zi3 & ai2)=3.58e8;n0(zi3 & ai2)=9.94e11; % [1,4]
    r0(zi4 & ai2)=rv+170e3;hs(zi4 & ai2)=3.58e8;n0(zi4 & ai2)=2.59e12; % [1,4]

    N=n0.*exp(hs.*(1./r-1./r0)).*zetapartbalesc2(hs,r0,hs./r);

  case 'H_hot'
    zi=sza<pi/2;                % True on the dayside
      Nzi=(1-2*sza/pi).*exp([-6.2625e-05 15.4817 3.6414e+04]* ...
	    (ones(3,1)*(r*1e-3)).^([1;0;-1]*ones(size(r))) ) + ...
        (2*sza/pi).*exp([-8.4607e-05 15.9944 2.9743e+04]* ...
	    (ones(3,1)*(r*1e-3)).^([1;0;-1]*ones(size(r))) );
      Nzinot=(2-2*sza/pi).*exp([-8.4607e-05 15.9944 2.9743e+04]* ...
	    (ones(3,1)*(r*1e-3)).^([1;0;-1]*ones(size(r))) ) + ...
        (2*sza/pi-1).*exp([-6.2309e-05 15.2723 4.3781e+04]* ...
	    (ones(3,1)*(r*1e-3)).^([1;0;-1]*ones(size(r))) );
	N=Nzi.*zi + Nzinot.*(~zi);
	
  case 'O_the'
    zi1 = sza< 1.9284;
    hs=6.3e+11./(314 - 44.1*sza.^2);
    hs(~zi1)=4.2e9;                                        % [5]
    r0=rv+170e3; n0=10.^(14.5+0.46*cos(sza));              % [5]
    N=n0.*exp(hs.*(1./r-1/r0)).*zetapart2(hs,r0,hs./r);

  case 'O_hot'
    zi1 = sza < pi/2;
    r0(zi1)=rv+200e3; hs(zi1) = 9.845e7; n0(zi1) = 7.5e10; % [3]
    r0(~zi1)=rv+300e3; hs(~zi1) = 1.3e8; n0(~zi1) = 2e9;   % [2]
    N=n0.*exp(hs.*(1./r-1./r0)).*zetapart2(hs,r0,hs./r);

  case 'He'
    zi1 = sza<pi/6;                               % True if SZA<30 deg
    zi2 = ~zi1 & sza<pi/3;                        % True if 30 deg<SZA<60 deg
    zi3 = ~zi1 & ~zi2 & sza<pi/2;                 % True if 60<SZA<90 deg
    zi4 = ~zi1 & ~zi2 & ~zi3 & sza<2*pi/3;        % True if 90<SZA<120 deg
    zi5 = ~zi1 & ~zi2 & ~zi3 & ~zi4 & sza<5*pi/6; % True if 120<SZA<150 deg
    zi6 = ~zi1 & ~zi2 & ~zi3 & ~zi4 & ~zi5;       % True if SZA>150 deg
    ai1 = aza<pi/6 | aza>11*pi/6;  % True in the bulge
    ai2 = ~ai1;                    % True outside the bulge
    
    r0=rv+170e3;
    hs(zi1 & ai1)=5.20e8; n0(zi1 & ai1)=2.0e12;  % [5]
    hs(zi2 & ai1)=5.94e8; n0(zi2 & ai1)=4.7e12;  % [5]
    hs(zi3 & ai1)=7.40e8; n0(zi3 & ai1)=2.11e13; % [5]
    hs(zi4 & ai1)=9.38e8; n0(zi4 & ai1)=4.64e13; % [5]
    hs(zi5 & ai1)=1.06e9; n0(zi5 & ai1)=1.86e13; % [5]
    hs(zi6 & ai1)=1.09e9; n0(zi6 & ai1)=1.48e13; % [5]

    hs(zi1 & ai2)=5.08e8; n0(zi1 & ai2)=1.3e12;  % [5]
    hs(zi2 & ai2)=5.43e8; n0(zi2 & ai2)=1.6e12;  % [5]
    hs(zi3 & ai2)=6.51e8; n0(zi3 & ai2)=2.8e12;  % [5]
    hs(zi4 & ai2)=8.51e8; n0(zi4 & ai2)=4.7e12;  % [5]
    hs(zi5 & ai2)=9.97e8; n0(zi5 & ai2)=8.0e12;  % [5]
    hs(zi6 & ai2)=1.05e9; n0(zi6 & ai2)=1.14e13; % [5]
    
     N=n0.*exp(hs.*(1./r-1/r0)).*zetapartbalesc2(hs,r0,hs./r);

  otherwise
	error('Illegal species!')
end     % end switch species

% [1] Brinton et al. GRL vol 7, 865 (1980)
% [2] Nagy et al. GRL vol 8,629 (1981)
% [3] M. B. McElroy et al. GRL, vol. 9, 649 (1982)
% [4] J. M. Rodriguez et al., Planet. Space Sci., vol 32, 1235 (1984)
% [5] J. G. Mengel et al., Planet. Space Sci. vol 37, 707 (1989)
